@@ -34,7 +34,7 @@ use Sim::OPT::Parcoord3d;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.143';
+$VERSION = '0.145';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -703,7 +703,9 @@ sub wei
   my %factlevels = %{ $factlevels_ref };  #say $tee "AND \%factlevels: " . dump( %factlevels );
   # my ( %magic, %wand, %spell, %bank );
   my %bank = %{ $bank_ref };
-  my %nears = %{ $nears_ref };
+  my %nears = %{ $nears_ref }; say $tee " \%nearsIN1: " . dump( \%nears );
+
+  my %weldnears;
 
 ###--###
   my @weldsprepared = @{ $weldsprepared_ref }; #say $tee "NOW \@weldsprepared: " . dump( @weldsprepared );
@@ -754,11 +756,12 @@ sub wei
 
   sub fillbank
   { #say $tee "NOW IN FILLBANK.";
+    say $tee " \%nearsIN2: " . dump( \%nears );
     my ( $arr_r, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, $factlevels_r, $nfilter, $arra_r, $first0, $last0, $nears_ref ) = @_;
     my @arr = @{ $arr_r };
     my @arra = @{ $arra_r };
     my %factlevels = %{ $factlevels_r };
-
+    my %nears = %{ $nears_ref }; say $tee " \%nearsIN3: " . dump( \%nears );
     #my $nstop;
     #if ( $nfilter ne "" )
     #{
@@ -1063,6 +1066,7 @@ sub wei
         {
           push ( @{ $bank{$trio}{orderedtrio} }, @{ $weldbank{$trio}{orderedtrio} } );
           push ( @{ $bank{$trio}{grad} }, @{ $weldbank{$trio}{grad} } );
+          push ( @{ $bank{$trio}{grads} }, @{ $weldbank{$trio}{grads} } );
           push ( @{ $bank{$trio}{ordists} }, @{ $weldbank{$trio}{ordists} } );
           push ( @{ $bank{$trio}{strengths} }, @{ $weldbank{$trio}{strengths} } );
           push ( @{ $bank{$trio}{orvals} }, @{ $weldbank{$trio}{orvals} } );
@@ -1076,7 +1080,9 @@ sub wei
     return( \%bank );
   }
 
-  unless ( ( scalar( @weldsprepared ) == 0 ) or ( $count > 0 ) )
+  unless ( ( scalar( @weldsprepared ) == 0 )
+  #or ( $count > 0 )
+  )
   { say $tee "Entering gradients' bank for welding.";
     my $co = 0;
     foreach my $weldref ( @weldaarrs )
@@ -1118,8 +1124,21 @@ sub wei
       {
         @weldarrb = @weldarr__;
       }
-      say $tee "FIRST0 $first0,  LAST0 $last0 ";
+
+
+      #foreach my $el ( @weldarr )
+      #{
+      #  if ( ( $weldnears{$el->[0]}{all}->[2] eq "" ) or ( ( $weldnears{$el->[0]}{all}->[3] < 1 ) and ( $weldnears{$el->[0]}{all}->[2] != $el->[2] ) ) )
+      #  {
+      #    $weldnears{$el->[0]}{all} = $el;
+      #  }
+      #}
+      #say $tee " \%weldnears: " . dump( \%weldnears );
+
+      #say $tee "FIRST0 $first0,  LAST0 $last0 ";
       #say $tee " \@weldarr__: " . dump( \@weldarr__ ) ;
+      #say $tee " \%factlevels: " . dump( \%factlevels ) ;
+      #say $tee " \@weldarra: " . dump( \@weldarra ) ;
       my ( $weldbank_ref, $weldnears_ref ) = fillbank( \@weldarr__, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, \%factlevels, $nfilter, \@weldarra, $first0, $last0, \%nears );
       %weldbank = %{ $weldbank_ref }; say $tee " \%weldbank: " . dump( \%weldbank ) ;
       %weldnears = %{ $weldnears_ref };
@@ -1486,7 +1505,7 @@ sub purelin
                         $indinc--;
                       }
                     }
-                    $co++;
+                    $co++;$nears_ref
                   }
                   $count++;
                 }
@@ -2054,11 +2073,11 @@ sub interlinear
 
       @limbo_wei = @{ $limbo_wei_ref };
       %bank = %{ $bank_ref };
-      %nears = %{ $nears_ref };
+      %nears = %{ $nears_ref }; say $tee "OBTAINED \%nears: " . dump( \%nears );
 
       say $tee "THERE ARE " . scalar( @limbo_wei ) . " ITEMS IN THIS LOOP , NUMBER " . ( $count + 1 ). ", 1, FOR WEIGHTED GRADIENT INTERPOLATION OF THE NEAREST NEIGHBOUR.";
     }
-    #say $tee "OBTAINED LIMBO_WEI: " . dump( @limbo_wei );
+    say $tee "OBTAINED LIMBO_WEI: " . dump( @limbo_wei );
 
     if ( ( $mode__ eq "purelin" ) or ( $mode__ eq "mix" ) )
     {
